"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var logger_1 = require("hornet-js-utils/src/logger");
var test_logger_1 = require("hornet-js-test/src/test-logger");
logger_1.Logger.prototype.buildLogger = test_logger_1.TestLogger.getLoggerBuilder({
    "appenders": {
        "console": {
            "type": "console",
            "layout": {
                "type": "pattern",
                "pattern": "%[%d{ISO8601}|%p|%c|%m%]"
            }
        }
    },
    "categories": {
        "default": { "appenders": ["console"], "level": "INFO" }
    }
});
var test_utils_1 = require("hornet-js-test/src/test-utils");
var chai = test_utils_1.TestUtils.chai;
var expect = chai.expect;
var cancellable_promise_1 = require("hornet-js-utils/src/cancellable-promise");
var cpt = 0;
var base_mocha_test_1 = require("hornet-js-test/src/base-mocha-test");
var decorators_1 = require("hornet-js-test/src/decorators");
var test_run_1 = require("hornet-js-test/src/test-run");
var index_1 = require("hornet-js-utils/src/index");
var cls = index_1.Utils.getContinuationStorage();
var CancellablePromiseTest = /** @class */ (function (_super) {
    tslib_1.__extends(CancellablePromiseTest, _super);
    function CancellablePromiseTest() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancellablePromiseTest.prototype.beforeEach = function () {
        cpt = 0;
    };
    CancellablePromiseTest.prototype.testCancelPromise = function () {
        var _this = this;
        cls.run(function () {
            cancellable_promise_1.CancellablePromise.getPromise(function (resolve, reject, onCancel) {
                var id = setTimeout(function () {
                    cpt = 3;
                    resolve(1);
                }, 250);
                onCancel(function () { return clearTimeout(id); });
            });
            setTimeout(function () {
                cancellable_promise_1.CancellablePromise.clearAllCancellablePromises();
                setTimeout(function () {
                    expect(cpt, "promesse non annulée").to.be.equal(0);
                    _this.end();
                }, 250);
            }, 50);
        });
    };
    CancellablePromiseTest.prototype.testPromiseOk = function () {
        var _this = this;
        cls.run(function () {
            cancellable_promise_1.CancellablePromise.getPromise(function (resolve, reject, onCancel) {
                var id = setTimeout(function () {
                    cpt = 3;
                    resolve(1);
                }, 250);
                onCancel(function () { return clearTimeout(id); });
            });
            setTimeout(function () {
                expect(cpt, "promesse annulée").to.be.equal(3);
                _this.end();
            }, 350);
        });
    };
    CancellablePromiseTest.prototype.testCancelNamedPromise = function () {
        var _this = this;
        cls.run(function () {
            cancellable_promise_1.CancellablePromise.getNamedPromise(function (resolve, reject, onCancel) {
                var id = setTimeout(function () {
                    cpt = 3;
                    resolve(1);
                }, 250);
                onCancel(function () { return clearTimeout(id); });
            }, "testUnit");
            setTimeout(function () {
                cancellable_promise_1.CancellablePromise.clearAllCancellablePromises(true);
                setTimeout(function () {
                    expect(cpt, "named promesse non annulée avec clearAllCancellablePromises").to.be.equal(0);
                    _this.end();
                }, 250);
            }, 50);
        });
    };
    CancellablePromiseTest.prototype.testCancelNotNamedPromise = function () {
        var _this = this;
        cls.run(function () {
            cancellable_promise_1.CancellablePromise.getNamedPromise(function (resolve, reject, onCancel) {
                var id = setTimeout(function () {
                    cpt = 3;
                    resolve(1);
                }, 250);
                onCancel(function () { return clearTimeout(id); });
            }, "testUnit1");
            setTimeout(function () {
                cancellable_promise_1.CancellablePromise.clearAllCancellablePromises(false);
                setTimeout(function () {
                    expect(cpt, "named promesse annulée avec clearAllCancellablePromises à false").to.be.equal(3);
                    _this.end();
                }, 250);
            }, 50);
        });
    };
    CancellablePromiseTest.prototype.testCancelPromiseNamedWith = function () {
        var _this = this;
        cls.run(function () {
            cancellable_promise_1.CancellablePromise.getNamedPromise(function (resolve, reject, onCancel) {
                var id = setTimeout(function () {
                    cpt = 3;
                    resolve(1);
                }, 250);
                onCancel(function () { return clearTimeout(id); });
            }, "testUnit2");
            setTimeout(function () {
                cancellable_promise_1.CancellablePromise.cancelPromiseWithName("testUnit2");
                setTimeout(function () {
                    expect(cpt, "named promesse non annulée avec cancelPromiseWithName").to.be.equal(0);
                    _this.end();
                }, 250);
            }, 50);
        });
    };
    CancellablePromiseTest.prototype.testUnregisterNamedPromise = function () {
        var _this = this;
        cls.run(function () {
            cancellable_promise_1.CancellablePromise.getNamedPromise(function (resolve, reject, onCancel) {
                var id = setTimeout(function () {
                    cpt = 3;
                    resolve(1);
                }, 250);
                onCancel(function () { return clearTimeout(id); });
            }, "testUnit3");
            setTimeout(function () {
                var promises = index_1.Utils.getCls("cancellablePromise");
                expect(promises["testUnit3"], "promesse nommée non présente dans le cls").to.exist;
                cancellable_promise_1.CancellablePromise.unregisterPromiseInClsWithName("testUnit3");
                setTimeout(function () {
                    var promises = index_1.Utils.getCls("cancellablePromise");
                    expect(promises["testUnit3"], "promesse nommée présente dans le cls").to.not.exist;
                    _this.end();
                }, 250);
            }, 50);
        });
    };
    tslib_1.__decorate([
        decorators_1.Decorators.beforeEach
    ], CancellablePromiseTest.prototype, "beforeEach", null);
    tslib_1.__decorate([
        decorators_1.Decorators.it("Test cancel cancellable promise")
    ], CancellablePromiseTest.prototype, "testCancelPromise", null);
    tslib_1.__decorate([
        decorators_1.Decorators.it("Test cancellable promise")
    ], CancellablePromiseTest.prototype, "testPromiseOk", null);
    tslib_1.__decorate([
        decorators_1.Decorators.it("Test cancel named cancellable promise")
    ], CancellablePromiseTest.prototype, "testCancelNamedPromise", null);
    tslib_1.__decorate([
        decorators_1.Decorators.it("Test cancel not named cancellable promise")
    ], CancellablePromiseTest.prototype, "testCancelNotNamedPromise", null);
    tslib_1.__decorate([
        decorators_1.Decorators.it("Test cancel named cancellable promise avec cancelPromiseWithName ")
    ], CancellablePromiseTest.prototype, "testCancelPromiseNamedWith", null);
    tslib_1.__decorate([
        decorators_1.Decorators.it("Test désenregistrer named cancellable promise")
    ], CancellablePromiseTest.prototype, "testUnregisterNamedPromise", null);
    CancellablePromiseTest = tslib_1.__decorate([
        decorators_1.Decorators.describe("Test cancellable promise")
    ], CancellablePromiseTest);
    return CancellablePromiseTest;
}(base_mocha_test_1.BaseMochaTest));
// lancement des Tests
test_run_1.runTest(new CancellablePromiseTest());

//# sourceMappingURL=cancellable-promise-spec.js.map
